import { z } from "zod";
export declare enum RateType {
    VARIABLE = 0,
    FIXED = 1
}
export declare enum Amortization {
    ANNUITET = 0,
    SERIE = 1,
    REVOLVING = 2
}
export declare enum AccountType {
    LOAN = "LOAN",
    LEASING = "LEASING",
    DEPOSIT = "DEPOSIT",
    FACOTRING = "FACOTRING"
}
export declare enum AccountSubType {
    "INSTALLMENT LOAN" = "INSTALLMENT LOAN",
    "REVOLVING CREDIT" = "REVOLVING CREDIT",
    "RECOURSE" = "RECOURSE",
    "NON-RECOURSE" = "NON-RECOURSE",
    "ADMIN" = "ADMIN",
    "HYBRID" = "HYBRID"
}
export declare const reserveAccountRequestQuerySchema: z.ZodObject<{
    correlationId: z.ZodOptional<z.ZodString>;
    sourceSystemCode: z.ZodString;
    sourceApplicationId: z.ZodString;
    accountTypeCode: z.ZodNativeEnum<typeof AccountType>;
    accountSubtypeCode: z.ZodNativeEnum<typeof AccountSubType>;
    countryIds: z.ZodString;
    businessAreaIds: z.ZodString;
}, "strip", z.ZodTypeAny, {
    correlationId?: string | undefined;
    sourceSystemCode: string;
    sourceApplicationId: string;
    accountTypeCode: AccountType;
    accountSubtypeCode: AccountSubType;
    countryIds: string;
    businessAreaIds: string;
}, {
    correlationId?: string | undefined;
    sourceSystemCode: string;
    sourceApplicationId: string;
    accountTypeCode: AccountType;
    accountSubtypeCode: AccountSubType;
    countryIds: string;
    businessAreaIds: string;
}>;
export declare type ReserveAccountQueryRequest = z.infer<typeof reserveAccountRequestQuerySchema>;
export declare const createAccountRequestQuerySchema: z.ZodObject<{
    correlationId: z.ZodOptional<z.ZodString>;
    countryIds: z.ZodString;
    businessAreaIds: z.ZodString;
}, "strip", z.ZodTypeAny, {
    correlationId?: string | undefined;
    countryIds: string;
    businessAreaIds: string;
}, {
    correlationId?: string | undefined;
    countryIds: string;
    businessAreaIds: string;
}>;
export declare type CreateAccountRequestQuery = z.infer<typeof createAccountRequestQuerySchema>;
export declare const createAccountRequestSchema: z.ZodObject<{
    newAccountApplication: z.ZodObject<{
        account: z.ZodObject<{
            sourceSystemCode: z.ZodString;
            sourceApplicationID: z.ZodString;
            sourceProductID: z.ZodString;
            accountTypeCode: z.ZodNativeEnum<typeof AccountType>;
            accountSubtypeCode: z.ZodNativeEnum<typeof AccountSubType>;
            originationDate: z.ZodEffects<z.ZodString, string, string>;
            startDate: z.ZodEffects<z.ZodString, string, string>;
            contractTypeCode: z.ZodOptional<z.ZodString>;
            limitAmount: z.ZodOptional<z.ZodNumber>;
            limitExpiryDate: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            dueDay: z.ZodNumber;
            interestGroupCode: z.ZodString;
            baseInterestRate: z.ZodOptional<z.ZodNumber>;
            nominalInterestRate: z.ZodNumber;
            netLoanAmount: z.ZodNumber;
            objectPrice: z.ZodNumber;
            equityAmount: z.ZodOptional<z.ZodNumber>;
            vatRate: z.ZodOptional<z.ZodNumber>;
            vatAmount: z.ZodOptional<z.ZodNumber>;
            contractDocTitle: z.ZodOptional<z.ZodString>;
            contractDocURL: z.ZodOptional<z.ZodString>;
            requireDirectDebit: z.ZodOptional<z.ZodBoolean>;
            directDebitAccountNo: z.ZodOptional<z.ZodString>;
            directDebitAmountLimit: z.ZodOptional<z.ZodNumber>;
            initiateDirectDebit: z.ZodOptional<z.ZodBoolean>;
            iban: z.ZodOptional<z.ZodString>;
            factoringInvoiceLimit: z.ZodOptional<z.ZodNumber>;
            disbursementBankAccountNo: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            sourceProductID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            interestGroupCode: string;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
        }, {
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            sourceProductID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            interestGroupCode: string;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
        }>;
        accountDimension: z.ZodOptional<z.ZodArray<z.ZodObject<{
            dimensionCode: z.ZodString;
            dimensionValue: z.ZodString;
            dimensionDescription: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }, {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }>, "many">>;
        product: z.ZodObject<{
            sourceProductID: z.ZodString;
            productName: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            sourceProductID: string;
            productName: string;
        }, {
            sourceProductID: string;
            productName: string;
        }>;
        paymentSeries: z.ZodArray<z.ZodObject<{
            legNo: z.ZodNumber;
            termLength: z.ZodNumber;
            termCount: z.ZodNumber;
            minAmountTermCount: z.ZodOptional<z.ZodNumber>;
            minAmountTermCountMax: z.ZodOptional<z.ZodNumber>;
            rateType: z.ZodNativeEnum<typeof RateType>;
            termDue: z.ZodOptional<z.ZodNumber>;
            amortization: z.ZodNativeEnum<typeof Amortization>;
            interestRate: z.ZodNumber;
            startBalance: z.ZodNumber;
            endBalance: z.ZodNumber;
            termFee: z.ZodNumber;
            netTermAmount: z.ZodOptional<z.ZodNumber>;
            grossTermAmount: z.ZodOptional<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
        }, {
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
        }>, "many">;
        contact: z.ZodArray<z.ZodObject<{
            sourceSystemCode: z.ZodString;
            sourceContactID: z.ZodString;
            contactRoleCode: z.ZodEnum<["SIGNER", "COSIGNER", "GUARANTOR", "VENDOR", "BROKER", "SALESPERSON", "INTERNALUNDERWRITER", "INTERNALSALESPERSON", "REPURCHASER", "SUPPLIER", "INSURANCE", "CONTACTPERSON", "UBO", "POA", "OTHER"]>;
            otherRole: z.ZodOptional<z.ZodString>;
            accountShare: z.ZodOptional<z.ZodNumber>;
            organizationNo: z.ZodOptional<z.ZodString>;
            socialSecurityNo: z.ZodString;
            dateOfBirthOrReg: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            sectorCode: z.ZodOptional<z.ZodString>;
            economicActivityCode: z.ZodOptional<z.ZodString>;
            legalEntityTypeCode: z.ZodOptional<z.ZodString>;
            companyName: z.ZodOptional<z.ZodString>;
            firstName: z.ZodString;
            middleName: z.ZodString;
            surname: z.ZodString;
            salutationCode: z.ZodOptional<z.ZodString>;
            jobTitle: z.ZodOptional<z.ZodString>;
            eMail: z.ZodString;
            invoiceEMail: z.ZodOptional<z.ZodString>;
            reminderEMail: z.ZodOptional<z.ZodString>;
            phoneNo: z.ZodOptional<z.ZodString>;
            mobilePhoneNo: z.ZodString;
            nationalityCode: z.ZodEnum<["NO"]>;
            address: z.ZodString;
            address2: z.ZodOptional<z.ZodString>;
            streetType: z.ZodOptional<z.ZodString>;
            postCode: z.ZodString;
            city: z.ZodString;
            region: z.ZodOptional<z.ZodString>;
            countryCode: z.ZodEnum<["NO"]>;
            languageCode: z.ZodEnum<["NOR"]>;
            guarantorType: z.ZodOptional<z.ZodString>;
            guarantorAmount: z.ZodOptional<z.ZodNumber>;
            guarantorExpiryDate: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            bankAccountNo: z.ZodOptional<z.ZodString>;
            bankAccountOwnershipVerified: z.ZodOptional<z.ZodBoolean>;
            bankAccountOwnershipVerificationComment: z.ZodOptional<z.ZodString>;
            pep: z.ZodEnum<["NO PEP", "PEP", "PEP Relative", "PEP Associate"]>;
            riskLevelAML: z.ZodOptional<z.ZodString>;
            citizenshipCode: z.ZodArray<z.ZodEnum<["NO"]>, "many">;
            taxIdentification: z.ZodOptional<z.ZodArray<z.ZodObject<{
                countryCode: z.ZodString;
                taxIdNumber: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                countryCode: string;
                taxIdNumber: string;
            }, {
                countryCode: string;
                taxIdNumber: string;
            }>, "many">>;
            kycAnswer: z.ZodOptional<z.ZodArray<z.ZodObject<{
                questionID: z.ZodString;
                answer: z.ZodString;
                timestamp: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                questionID: string;
                answer: string;
                timestamp: string;
            }, {
                questionID: string;
                answer: string;
                timestamp: string;
            }>, "many">>;
            dateOfLastKYC: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
        }, "strip", z.ZodTypeAny, {
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            bankAccountNo?: string | undefined;
            bankAccountOwnershipVerified?: boolean | undefined;
            bankAccountOwnershipVerificationComment?: string | undefined;
            riskLevelAML?: string | undefined;
            taxIdentification?: {
                countryCode: string;
                taxIdNumber: string;
            }[] | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp: string;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            sourceSystemCode: string;
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: "NO";
            address: string;
            postCode: string;
            city: string;
            countryCode: "NO";
            languageCode: "NOR";
            pep: "NO PEP" | "PEP" | "PEP Relative" | "PEP Associate";
            citizenshipCode: "NO"[];
        }, {
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            bankAccountNo?: string | undefined;
            bankAccountOwnershipVerified?: boolean | undefined;
            bankAccountOwnershipVerificationComment?: string | undefined;
            riskLevelAML?: string | undefined;
            taxIdentification?: {
                countryCode: string;
                taxIdNumber: string;
            }[] | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp: string;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            sourceSystemCode: string;
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: "NO";
            address: string;
            postCode: string;
            city: string;
            countryCode: "NO";
            languageCode: "NOR";
            pep: "NO PEP" | "PEP" | "PEP Relative" | "PEP Associate";
            citizenshipCode: "NO"[];
        }>, "many">;
        disbursement: z.ZodArray<z.ZodObject<{
            sourceDisbursementID: z.ZodString;
            recipientType: z.ZodEnum<["CUSTOMER", "VENDOR", "INTERNALACCOUNT"]>;
            sourceContactID: z.ZodString;
            coreAccountNo: z.ZodOptional<z.ZodString>;
            bankAccountNo: z.ZodString;
            paymentDate: z.ZodEffects<z.ZodString, string, string>;
            currency: z.ZodOptional<z.ZodString>;
            amount: z.ZodNumber;
            externalDocNo: z.ZodString;
            paymentReference: z.ZodOptional<z.ZodString>;
            paymentText: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            coreAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            sourceContactID: string;
            bankAccountNo: string;
            sourceDisbursementID: string;
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            externalDocNo: string;
            paymentText: string;
        }, {
            coreAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            sourceContactID: string;
            bankAccountNo: string;
            sourceDisbursementID: string;
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            externalDocNo: string;
            paymentText: string;
        }>, "many">;
        commission: z.ZodOptional<z.ZodArray<z.ZodObject<{
            sourceCommissionID: z.ZodString;
            commissionTypeCode: z.ZodString;
            commissionCode: z.ZodString;
            commissionRecipient: z.ZodString;
            commissionRecipientID: z.ZodString;
            commissionBaseType: z.ZodString;
            commissionAmount: z.ZodNumber;
            commissionValueType: z.ZodString;
            commissionValue: z.ZodNumber;
            commissionMargin: z.ZodNumber;
            commissionTermCount: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            sourceCommissionID: string;
            commissionTypeCode: string;
            commissionCode: string;
            commissionRecipient: string;
            commissionRecipientID: string;
            commissionBaseType: string;
            commissionAmount: number;
            commissionValueType: string;
            commissionValue: number;
            commissionMargin: number;
            commissionTermCount: number;
        }, {
            sourceCommissionID: string;
            commissionTypeCode: string;
            commissionCode: string;
            commissionRecipient: string;
            commissionRecipientID: string;
            commissionBaseType: string;
            commissionAmount: number;
            commissionValueType: string;
            commissionValue: number;
            commissionMargin: number;
            commissionTermCount: number;
        }>, "many">>;
        fee: z.ZodArray<z.ZodObject<{
            sourceFeeID: z.ZodOptional<z.ZodString>;
            feeTypeCode: z.ZodOptional<z.ZodString>;
            feeCode: z.ZodEnum<["TINGLYSING"]>;
            feeAmountType: z.ZodOptional<z.ZodString>;
            feeAmount: z.ZodNumber;
            feeValueType: z.ZodOptional<z.ZodString>;
            feeValue: z.ZodOptional<z.ZodNumber>;
            includeInInterestCalc: z.ZodBoolean;
            feeIsFinanced: z.ZodBoolean;
        }, "strip", z.ZodTypeAny, {
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
            feeCode: "TINGLYSING";
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
        }, {
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
            feeCode: "TINGLYSING";
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
        }>, "many">;
        brand: z.ZodArray<z.ZodObject<{
            brandCode: z.ZodString;
            brandOrgNo: z.ZodOptional<z.ZodString>;
            brandCompany: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
            brandCode: string;
        }, {
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
            brandCode: string;
        }>, "many">;
        additionalProduct: z.ZodOptional<z.ZodArray<z.ZodObject<{
            productCode: z.ZodString;
            startDate: z.ZodEffects<z.ZodString, string, string>;
            endDate: z.ZodEffects<z.ZodString, string, string>;
            priceCalcType: z.ZodString;
            priceCalcValue: z.ZodNumber;
            consentDate: z.ZodEffects<z.ZodString, string, string>;
            freeTerms: z.ZodNumber;
            minimumPrice: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            startDate: string;
            productCode: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }, {
            startDate: string;
            productCode: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }>, "many">>;
        object: z.ZodArray<z.ZodObject<{
            sourceObjectID: z.ZodString;
            objectIdNumber: z.ZodOptional<z.ZodString>;
            objectDescription: z.ZodString;
            objectDescriptionLong: z.ZodOptional<z.ZodString>;
            objectMake: z.ZodOptional<z.ZodString>;
            objectModel: z.ZodOptional<z.ZodString>;
            objectEngine: z.ZodOptional<z.ZodString>;
            objectYear: z.ZodOptional<z.ZodNumber>;
            objectIsFinanced: z.ZodOptional<z.ZodBoolean>;
            installationInfo: z.ZodOptional<z.ZodString>;
            insuranceName: z.ZodOptional<z.ZodString>;
            insuranceOrgNo: z.ZodOptional<z.ZodString>;
            insurancePolicyNo: z.ZodOptional<z.ZodString>;
            insuranceInfo: z.ZodOptional<z.ZodString>;
            objectGroupCode: z.ZodOptional<z.ZodString>;
            objectSubgroupCode: z.ZodOptional<z.ZodString>;
            objectConditionCode: z.ZodOptional<z.ZodNumber>;
            depotValue: z.ZodNumber;
            depotValueFactor: z.ZodOptional<z.ZodNumber>;
            depotDepreciationFactor: z.ZodOptional<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotValueFactor?: number | undefined;
            depotDepreciationFactor?: number | undefined;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
        }, {
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotValueFactor?: number | undefined;
            depotDepreciationFactor?: number | undefined;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
        }>, "many">;
        security: z.ZodOptional<z.ZodArray<z.ZodObject<{
            sourceSecurityID: z.ZodOptional<z.ZodString>;
            sourceObjectID: z.ZodString;
            sourceContactID: z.ZodString;
            securityTypeCode: z.ZodString;
            securityFaceValue: z.ZodNumber;
            securityExpirationDate: z.ZodEffects<z.ZodString, string, string>;
            securityOrderOfPriority: z.ZodNumber;
            securityOfficialRegistrationDocNo: z.ZodString;
            securityPriorityAmount: z.ZodNumber;
            securityPriorityEqualToAmount: z.ZodNumber;
            securityDescription: z.ZodString;
            securityRegistrationDate: z.ZodEffects<z.ZodString, string, string>;
        }, "strip", z.ZodTypeAny, {
            sourceSecurityID?: string | undefined;
            sourceContactID: string;
            sourceObjectID: string;
            securityTypeCode: string;
            securityFaceValue: number;
            securityExpirationDate: string;
            securityOrderOfPriority: number;
            securityOfficialRegistrationDocNo: string;
            securityPriorityAmount: number;
            securityPriorityEqualToAmount: number;
            securityDescription: string;
            securityRegistrationDate: string;
        }, {
            sourceSecurityID?: string | undefined;
            sourceContactID: string;
            sourceObjectID: string;
            securityTypeCode: string;
            securityFaceValue: number;
            securityExpirationDate: string;
            securityOrderOfPriority: number;
            securityOfficialRegistrationDocNo: string;
            securityPriorityAmount: number;
            securityPriorityEqualToAmount: number;
            securityDescription: string;
            securityRegistrationDate: string;
        }>, "many">>;
        accountDocument: z.ZodArray<z.ZodObject<{
            sentForReservation: z.ZodOptional<z.ZodBoolean>;
            sourceDocumentGUID: z.ZodString;
            documentType: z.ZodString;
            documentTitle: z.ZodString;
            documentURL: z.ZodString;
            documentContent: z.ZodOptional<z.ZodString>;
            documentContentFileType: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            sentForReservation?: boolean | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            sourceDocumentGUID: string;
            documentType: string;
            documentTitle: string;
            documentURL: string;
        }, {
            sentForReservation?: boolean | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            sourceDocumentGUID: string;
            documentType: string;
            documentTitle: string;
            documentURL: string;
        }>, "many">;
        text: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        accountDimension?: {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }[] | undefined;
        commission?: {
            sourceCommissionID: string;
            commissionTypeCode: string;
            commissionCode: string;
            commissionRecipient: string;
            commissionRecipientID: string;
            commissionBaseType: string;
            commissionAmount: number;
            commissionValueType: string;
            commissionValue: number;
            commissionMargin: number;
            commissionTermCount: number;
        }[] | undefined;
        additionalProduct?: {
            startDate: string;
            productCode: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }[] | undefined;
        security?: {
            sourceSecurityID?: string | undefined;
            sourceContactID: string;
            sourceObjectID: string;
            securityTypeCode: string;
            securityFaceValue: number;
            securityExpirationDate: string;
            securityOrderOfPriority: number;
            securityOfficialRegistrationDocNo: string;
            securityPriorityAmount: number;
            securityPriorityEqualToAmount: number;
            securityDescription: string;
            securityRegistrationDate: string;
        }[] | undefined;
        text?: string[] | undefined;
        object: {
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotValueFactor?: number | undefined;
            depotDepreciationFactor?: number | undefined;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
        }[];
        account: {
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            sourceProductID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            interestGroupCode: string;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
        };
        product: {
            sourceProductID: string;
            productName: string;
        };
        paymentSeries: {
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
        }[];
        contact: {
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            bankAccountNo?: string | undefined;
            bankAccountOwnershipVerified?: boolean | undefined;
            bankAccountOwnershipVerificationComment?: string | undefined;
            riskLevelAML?: string | undefined;
            taxIdentification?: {
                countryCode: string;
                taxIdNumber: string;
            }[] | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp: string;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            sourceSystemCode: string;
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: "NO";
            address: string;
            postCode: string;
            city: string;
            countryCode: "NO";
            languageCode: "NOR";
            pep: "NO PEP" | "PEP" | "PEP Relative" | "PEP Associate";
            citizenshipCode: "NO"[];
        }[];
        disbursement: {
            coreAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            sourceContactID: string;
            bankAccountNo: string;
            sourceDisbursementID: string;
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            externalDocNo: string;
            paymentText: string;
        }[];
        fee: {
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
            feeCode: "TINGLYSING";
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
        }[];
        brand: {
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
            brandCode: string;
        }[];
        accountDocument: {
            sentForReservation?: boolean | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            sourceDocumentGUID: string;
            documentType: string;
            documentTitle: string;
            documentURL: string;
        }[];
    }, {
        accountDimension?: {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }[] | undefined;
        commission?: {
            sourceCommissionID: string;
            commissionTypeCode: string;
            commissionCode: string;
            commissionRecipient: string;
            commissionRecipientID: string;
            commissionBaseType: string;
            commissionAmount: number;
            commissionValueType: string;
            commissionValue: number;
            commissionMargin: number;
            commissionTermCount: number;
        }[] | undefined;
        additionalProduct?: {
            startDate: string;
            productCode: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }[] | undefined;
        security?: {
            sourceSecurityID?: string | undefined;
            sourceContactID: string;
            sourceObjectID: string;
            securityTypeCode: string;
            securityFaceValue: number;
            securityExpirationDate: string;
            securityOrderOfPriority: number;
            securityOfficialRegistrationDocNo: string;
            securityPriorityAmount: number;
            securityPriorityEqualToAmount: number;
            securityDescription: string;
            securityRegistrationDate: string;
        }[] | undefined;
        text?: string[] | undefined;
        object: {
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotValueFactor?: number | undefined;
            depotDepreciationFactor?: number | undefined;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
        }[];
        account: {
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            sourceProductID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            interestGroupCode: string;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
        };
        product: {
            sourceProductID: string;
            productName: string;
        };
        paymentSeries: {
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
        }[];
        contact: {
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            bankAccountNo?: string | undefined;
            bankAccountOwnershipVerified?: boolean | undefined;
            bankAccountOwnershipVerificationComment?: string | undefined;
            riskLevelAML?: string | undefined;
            taxIdentification?: {
                countryCode: string;
                taxIdNumber: string;
            }[] | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp: string;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            sourceSystemCode: string;
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: "NO";
            address: string;
            postCode: string;
            city: string;
            countryCode: "NO";
            languageCode: "NOR";
            pep: "NO PEP" | "PEP" | "PEP Relative" | "PEP Associate";
            citizenshipCode: "NO"[];
        }[];
        disbursement: {
            coreAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            sourceContactID: string;
            bankAccountNo: string;
            sourceDisbursementID: string;
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            externalDocNo: string;
            paymentText: string;
        }[];
        fee: {
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
            feeCode: "TINGLYSING";
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
        }[];
        brand: {
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
            brandCode: string;
        }[];
        accountDocument: {
            sentForReservation?: boolean | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            sourceDocumentGUID: string;
            documentType: string;
            documentTitle: string;
            documentURL: string;
        }[];
    }>;
}, "strip", z.ZodTypeAny, {
    newAccountApplication: {
        accountDimension?: {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }[] | undefined;
        commission?: {
            sourceCommissionID: string;
            commissionTypeCode: string;
            commissionCode: string;
            commissionRecipient: string;
            commissionRecipientID: string;
            commissionBaseType: string;
            commissionAmount: number;
            commissionValueType: string;
            commissionValue: number;
            commissionMargin: number;
            commissionTermCount: number;
        }[] | undefined;
        additionalProduct?: {
            startDate: string;
            productCode: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }[] | undefined;
        security?: {
            sourceSecurityID?: string | undefined;
            sourceContactID: string;
            sourceObjectID: string;
            securityTypeCode: string;
            securityFaceValue: number;
            securityExpirationDate: string;
            securityOrderOfPriority: number;
            securityOfficialRegistrationDocNo: string;
            securityPriorityAmount: number;
            securityPriorityEqualToAmount: number;
            securityDescription: string;
            securityRegistrationDate: string;
        }[] | undefined;
        text?: string[] | undefined;
        object: {
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotValueFactor?: number | undefined;
            depotDepreciationFactor?: number | undefined;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
        }[];
        account: {
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            sourceProductID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            interestGroupCode: string;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
        };
        product: {
            sourceProductID: string;
            productName: string;
        };
        paymentSeries: {
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
        }[];
        contact: {
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            bankAccountNo?: string | undefined;
            bankAccountOwnershipVerified?: boolean | undefined;
            bankAccountOwnershipVerificationComment?: string | undefined;
            riskLevelAML?: string | undefined;
            taxIdentification?: {
                countryCode: string;
                taxIdNumber: string;
            }[] | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp: string;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            sourceSystemCode: string;
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: "NO";
            address: string;
            postCode: string;
            city: string;
            countryCode: "NO";
            languageCode: "NOR";
            pep: "NO PEP" | "PEP" | "PEP Relative" | "PEP Associate";
            citizenshipCode: "NO"[];
        }[];
        disbursement: {
            coreAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            sourceContactID: string;
            bankAccountNo: string;
            sourceDisbursementID: string;
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            externalDocNo: string;
            paymentText: string;
        }[];
        fee: {
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
            feeCode: "TINGLYSING";
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
        }[];
        brand: {
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
            brandCode: string;
        }[];
        accountDocument: {
            sentForReservation?: boolean | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            sourceDocumentGUID: string;
            documentType: string;
            documentTitle: string;
            documentURL: string;
        }[];
    };
}, {
    newAccountApplication: {
        accountDimension?: {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }[] | undefined;
        commission?: {
            sourceCommissionID: string;
            commissionTypeCode: string;
            commissionCode: string;
            commissionRecipient: string;
            commissionRecipientID: string;
            commissionBaseType: string;
            commissionAmount: number;
            commissionValueType: string;
            commissionValue: number;
            commissionMargin: number;
            commissionTermCount: number;
        }[] | undefined;
        additionalProduct?: {
            startDate: string;
            productCode: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }[] | undefined;
        security?: {
            sourceSecurityID?: string | undefined;
            sourceContactID: string;
            sourceObjectID: string;
            securityTypeCode: string;
            securityFaceValue: number;
            securityExpirationDate: string;
            securityOrderOfPriority: number;
            securityOfficialRegistrationDocNo: string;
            securityPriorityAmount: number;
            securityPriorityEqualToAmount: number;
            securityDescription: string;
            securityRegistrationDate: string;
        }[] | undefined;
        text?: string[] | undefined;
        object: {
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotValueFactor?: number | undefined;
            depotDepreciationFactor?: number | undefined;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
        }[];
        account: {
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            sourceProductID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            interestGroupCode: string;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
        };
        product: {
            sourceProductID: string;
            productName: string;
        };
        paymentSeries: {
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
        }[];
        contact: {
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            bankAccountNo?: string | undefined;
            bankAccountOwnershipVerified?: boolean | undefined;
            bankAccountOwnershipVerificationComment?: string | undefined;
            riskLevelAML?: string | undefined;
            taxIdentification?: {
                countryCode: string;
                taxIdNumber: string;
            }[] | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp: string;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            sourceSystemCode: string;
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: "NO";
            address: string;
            postCode: string;
            city: string;
            countryCode: "NO";
            languageCode: "NOR";
            pep: "NO PEP" | "PEP" | "PEP Relative" | "PEP Associate";
            citizenshipCode: "NO"[];
        }[];
        disbursement: {
            coreAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            sourceContactID: string;
            bankAccountNo: string;
            sourceDisbursementID: string;
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            externalDocNo: string;
            paymentText: string;
        }[];
        fee: {
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
            feeCode: "TINGLYSING";
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
        }[];
        brand: {
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
            brandCode: string;
        }[];
        accountDocument: {
            sentForReservation?: boolean | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            sourceDocumentGUID: string;
            documentType: string;
            documentTitle: string;
            documentURL: string;
        }[];
    };
}>;
export declare type CreateAccountRequest = z.infer<typeof createAccountRequestSchema>;
