import axios, { AxiosResponse } from "axios";
import {
  CreateAccountRequest,
  ReserveAccountQueryRequest,
} from "./schemas/accounts.schema";

/**
 * Reserve account
 * @param baseUrl - Baseurl to service url @defaults to http://services-code
 */
export async function reserveAccount(
  data: ReserveAccountQueryRequest,
  baseUrl: string = "http://services-code"
): Promise<any> {
  const response = await axios.post<any, AxiosResponse<any>>(
    `${baseUrl}/api/accounts/reservation`,
    null,
    { params: data }
  );
  return response.data;
}

/**
 * Create account
 * @param baseUrl - Baseurl to service url @defaults to http://services-code
 */
export async function createAccount(
  data: CreateAccountRequest,
  baseUrl: string = "http://services-code"
): Promise<any> {
  const response = await axios.post<any, AxiosResponse<any>>(
    `${baseUrl}/api/accounts`,
    data
  );
  return response.data;
}

export type { CreateAccountRequest, ReserveAccountQueryRequest };
